@@ -9,6 +9,7 @@ This python script is base script to connect Linux server by SSH.
 import sys
 from datetime import datetime
 from io import StringIO
+from paramiko.auth_handler import AuthenticationException, SSHException
 
 import paramiko
 
@@ -28,8 +29,11 @@ class SshClient:
             key = paramiko.RSAKey.from_private_key(StringIO(key), password=passphrase)
         try:
             self.client.connect(host, port, username=username, password=password, pkey=key, timeout=self.TIMEOUT)
+        except AuthenticationException as e:
+            self._print_log(f"Authentication failed: did you remember to create an SSH key? {e}")
+            raise str(e)
         except Exception as e:
-            raise Exception(f"Cannot connect to the SSH server: {str(e)}")
+            raise str(e)
 
     def close(self):
         """Close client."""
@@ -82,3 +86,39 @@ class SshClient:
         :param msg: message
         """
         sys.stdout.write(f"[{datetime.now().strftime(TIME_FORMAT)}]: {msg}\n")
+
+    def append_line_to_file(self, line, to_file):
+        """
+        Append a line in a remote file
+        :param line: A line of string
+        :param to_file: The file to be added the line
+        """
+        ftp = self.client.open_sftp()
+        try:
+            if not self.is_line_to_file(line, to_file):
+                edit_file = ftp.file(to_file, 'a+')
+                edit_file.write(f"\n{line}\n")
+                edit_file.flush()
+                self._print_log(f"Just added line [{line}] in file [{to_file}]")
+            else:
+                self._print_log(f"The line [{line}] is in file [{to_file}] already.")
+        finally:
+            ftp.close()
+
+    def is_line_to_file(self, line, to_file):
+        """
+        Append a line in a remote file
+        :param line: A line of string
+        :param to_file: The file to be added the line
+        :return: True if the line in the to_file, else False
+        """
+        ftp = self.client.open_sftp()
+        result = False
+        try:
+            edit_file = ftp.open(to_file, mode='r')
+            edit_file.prefetch()  # increase the read speed
+            if line in edit_file.read().decode():
+                result = True
+        finally:
+            ftp.close()
+            return result
